<?php
// Add settings page to the admin menu
add_action('admin_menu', 'wc_wa_notifications_add_admin_menu');
add_action('admin_init', 'wc_wa_notifications_settings_init');

// Add the settings page and Docs menu to the admin menu
function wc_wa_notifications_add_admin_menu() {
    // Add Settings page
    add_menu_page(
        'WhatsApp Notifications Settings',   // Page title
        'WhatsApp Notifications',            // Menu title
        'manage_options',                    // Capability
        'whatsapp_confirmation',             // Menu slug
        'wc_wa_notifications_options_page',  // Callback function
        'dashicons-whatsapp'                 // Icon URL (using Dashicons)
    );

    // Add Docs menu item
    add_submenu_page(
        'whatsapp_confirmation',            // Parent slug
        'Documentation',                    // Page title
        'Documentation',                    // Menu title
        'manage_options',                   // Capability
        'whatsapp_docs',                    // Menu slug
        'wc_wa_notifications_docs_page'    // Callback function
    );
}

// Initialize the settings
function wc_wa_notifications_settings_init() {
    register_setting('wc_wa_notifications', 'wc_whatsapp_company_name');
    register_setting('wc_wa_notifications', 'wc_whatsapp_message_template');
    register_setting('wc_wa_notifications', 'wc_whatsapp_status_message_template');

    add_settings_section(
        'wc_wa_notifications_section',
        'WhatsApp Notifications Settings',
        'wc_wa_notifications_section_callback',
        'wc_wa_notifications'
    );

    add_settings_field(
        'wc_whatsapp_company_name',
        'Company Name',
        'wc_whatsapp_company_name_render',
        'wc_wa_notifications',
        'wc_wa_notifications_section'
    );

    add_settings_field(
        'wc_whatsapp_message_template',
        'Confirmation Message Template',
        'wc_whatsapp_message_template_render',
        'wc_wa_notifications',
        'wc_wa_notifications_section'
    );

    add_settings_field(
        'wc_whatsapp_status_message_template',
        'Status Message Template',
        'wc_whatsapp_status_message_template_render',
        'wc_wa_notifications',
        'wc_wa_notifications_section'
    );
}

// Render the Company Name field
function wc_whatsapp_company_name_render() {
    $value = get_option('wc_whatsapp_company_name', '');
    echo '<input type="text" name="wc_whatsapp_company_name" value="' . esc_attr($value) . '" />';
}

// Render the Confirmation Message Template field
function wc_whatsapp_message_template_render() {
    $value = get_option('wc_whatsapp_message_template', '');
    echo '<textarea name="wc_whatsapp_message_template" rows="10" cols="50">' . esc_textarea($value) . '</textarea>';
}

// Render the Status Message Template field
function wc_whatsapp_status_message_template_render() {
    $value = get_option('wc_whatsapp_status_message_template', '');
    echo '<textarea name="wc_whatsapp_status_message_template" rows="10" cols="50">' . esc_textarea($value) . '</textarea>';
}

// Callback function for the settings section
function wc_wa_notifications_section_callback() {
    echo 'Enter your settings for WhatsApp messages.';
}

// Display the options page
function wc_wa_notifications_options_page() {
    ?>
    <div class="wrap">
        <h1>WhatsApp Notifications Settings</h1>
        <form action="options.php" method="post">
            <?php
            settings_fields('wc_wa_notifications');
            do_settings_sections('wc_wa_notifications');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Display the Documentation page
function wc_wa_notifications_docs_page() {
    ?>
    <div class="wrap">
        <h1>Documentation</h1>
        <p>Welcome to the documentation page. You can find the detailed documentation for the plugin here:</p>
        <ul>
            <li><a href="https://woosms.in/wooalerts-whatsapp-notifications-plugin-documentation" target="_blank">Plugin Documentation</a></li>
            <li><a href="https://woosms.in/download" target="_blank">WOOCOMMERCE SMS</a></li>
            <li><a href="https://woosms.in/support" target="_blank">Community Support</a></li>
        </ul>
    </div>
    <?php
}
?>
