<?php
add_action( 'wp_ajax_send_whatsapp_confirmation_message', 'wc_wa_notifications_send_whatsapp_confirmation_message' );
add_action( 'wp_ajax_send_whatsapp_status_message', 'wc_wa_notifications_send_whatsapp_status_message' );

function wc_wa_notifications_send_whatsapp_confirmation_message() {
    $order_id = intval( $_POST['order_id'] );
    $order = wc_get_order( $order_id );

    if ( ! $order ) {
        wp_send_json_error( array( 'message' => 'Order not found' ) );
        return;
    }

    $customer_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
    $order_number = $order->get_order_number();
    $order_date = $order->get_date_created()->date( 'Y-m-d' );
    $items_ordered = $order->get_items();
    $items_list = array();
    foreach ( $items_ordered as $item ) {
        $items_list[] = $item->get_name();
    }
    $total_amount = $order->get_total();
    $delivery_address = str_replace( '<br/>', ', ', $order->get_formatted_billing_address() );
    $customer_phone = $order->get_billing_phone();

    $template = get_option( 'wc_whatsapp_message_template', 'Dear {customer_name},\n\nThank you for shopping with us at {company_name}!\n\nWe have received your order with the following details:\n\n- Order Number: {order_number}\n- Order Date: {order_date}\n- Items Ordered:\n{items_list}\n- Total Amount: {total_amount}\n- Delivery Address: {delivery_address}\n\nTo proceed with your order, we kindly request you to confirm your Cash on Delivery (COD) order. Please reply to this message with your confirmation at your earliest convenience.\n\nIf you have any questions or need to make any changes to your order, please do not hesitate to contact us.\n\nThank you for choosing {company_name}.' );

    $message = str_replace(
        array( '{customer_name}', '{order_number}', '{order_date}', '{items_list}', '{total_amount}', '{delivery_address}', '{company_name}' ),
        array( $customer_name, $order_number, $order_date, implode( "\n  - ", $items_list ), $total_amount, $delivery_address, get_option( 'wc_whatsapp_company_name', 'Your Company Name' ) ),
        $template
    );

    $whatsapp_link = "https://wa.me/$customer_phone?text=" . urlencode( $message );

    wp_send_json_success( array( 'link' => $whatsapp_link ) );
}

function wc_wa_notifications_send_whatsapp_status_message() {
    $order_id = intval( $_POST['order_id'] );
    $order = wc_get_order( $order_id );

    if ( ! $order ) {
        wp_send_json_error( array( 'message' => 'Order not found' ) );
        return;
    }

    $customer_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
    $order_number = $order->get_order_number();
    $order_status = wc_get_order_status_name( $order->get_status() );
    $customer_phone = $order->get_billing_phone();

    $template = get_option( 'wc_whatsapp_status_message_template', 'Dear {customer_name},\n\nWe wanted to update you on the status of your order #{order_number}.\n\nCurrent Status: {order_status}\n\nIf you have any questions or need further assistance, please feel free to contact us.\n\nThank you for choosing {company_name}.' );

    $message = str_replace(
        array( '{customer_name}', '{order_number}', '{order_status}', '{company_name}' ),
        array( $customer_name, $order_number, $order_status, get_option( 'wc_whatsapp_company_name', 'Your Company Name' ) ),
        $template
    );

    $whatsapp_link = "https://wa.me/$customer_phone?text=" . urlencode( $message );

    wp_send_json_success( array( 'link' => $whatsapp_link ) );
}
