<?php
/*
Plugin Name: Woo Alert-WooCommerce WhatsApp Notifications
Description: Send WhatsApp notifications for WooCommerce order statuses and confirmation for COD orders without API.
Version: 1.3
Author: WooSMS.in
Author URI: https://woosms.in/
*/

// Add buttons to the WooCommerce order page
add_action('woocommerce_admin_order_data_after_order_details', 'add_whatsapp_buttons_to_order_page');

function add_whatsapp_buttons_to_order_page($order) {
    ?>
    <div style="margin-top: 20px;">
        <button id="cod-confirmation-button" onclick="sendWhatsAppConfirmationMessage(<?php echo $order->get_id(); ?>)" style="padding: 10px; background-color: #25D366; color: white; border: none; border-radius: 5px; cursor: pointer; margin-right: 10px;">COD CONFIRMATION</button>
        <button id="order-status-button" onclick="sendWhatsAppStatusMessage(<?php echo $order->get_id(); ?>)" style="padding: 10px; background-color: #25D366; color: white; border: none; border-radius: 5px; cursor: pointer; margin-right: 10px;">ORDER STATUS</button>
        <button id="purchase-now-button" style="padding: 10px; background-color: #25D366; color: white; border: none; border-radius: 5px; cursor: pointer;">PURCHASE NOW</button>
        <div id="whatsapp-error-message" style="display: none; margin-top: 20px; color: red;"></div>
    </div>
    <script>
        jQuery(document).ready(function($) {
            function showAlert(message) {
                // Show alert with error message
                alert(message);
            }

            function sendWhatsAppConfirmationMessage(orderId) {
                const data = {
                    action: 'send_whatsapp_confirmation_message',
                    order_id: orderId,
                    _ajax_nonce: '<?php echo wp_create_nonce('whatsapp_nonce'); ?>' // Add nonce
                };

                $.post(ajaxurl, data, function(response) {
                    if (response.success) {
                        const link = response.data.link;
                        console.log('WhatsApp Confirmation Link:', link); // Debugging
                        window.open(link, '_blank');
                    } else {
                        // Display the error message as HTML
                        $('#whatsapp-error-message').html(response.data.message).show();
                        showAlert(response.data.message); // Show alert
                    }
                });
            }

            function sendWhatsAppStatusMessage(orderId) {
                const data = {
                    action: 'send_whatsapp_status_message',
                    order_id: orderId,
                    _ajax_nonce: '<?php echo wp_create_nonce('whatsapp_nonce'); ?>' // Add nonce
                };

                $.post(ajaxurl, data, function(response) {
                    if (response.success) {
                        const link = response.data.link;
                        console.log('WhatsApp Status Link:', link); // Debugging
                        window.open(link, '_blank');
                    } else {
                        // Display the error message as HTML
                        $('#whatsapp-error-message').html(response.data.message).show();
                        showAlert(response.data.message); // Show alert
                    }
                });
            }

            window.sendWhatsAppConfirmationMessage = sendWhatsAppConfirmationMessage;
            window.sendWhatsAppStatusMessage = sendWhatsAppStatusMessage;
            
            // Handle Purchase Now button click
            $(document).on('click', '#purchase-now-button', function() {
                window.open("https://woosms.in/woo-alert-woocommerce-whatsapp-notifications-plugin/", "_blank");
            });
        });
    </script>
<?php
}

// Check usage limit before sending messages
function check_usage_limit() {
    $current_user_id = get_current_user_id();
    $usage_count = get_user_meta($current_user_id, 'wc_whatsapp_usage_count', true);

    if ($usage_count === '') {
        $usage_count = 0;
    }

    if ($usage_count >= 10) {
        $error_message = 'You have reached the usage limit. Please purchase the plugin to continue using it.';
        wp_send_json_error(array('message' => $error_message));
        return false;
    }

    return true;
}

// Increment usage count after sending messages
function increment_usage_count() {
    $current_user_id = get_current_user_id();
    $usage_count = get_user_meta($current_user_id, 'wc_whatsapp_usage_count', true);

    if ($usage_count === '') {
        $usage_count = 0;
    }

    $usage_count++;
    update_user_meta($current_user_id, 'wc_whatsapp_usage_count', $usage_count);
}

// Handle the AJAX request to send the WhatsApp confirmation message
add_action('wp_ajax_send_whatsapp_confirmation_message', 'send_whatsapp_confirmation_message');

function send_whatsapp_confirmation_message() {
    check_ajax_referer('whatsapp_nonce', '_ajax_nonce'); // Verify nonce

    if (!check_usage_limit()) {
        return;
    }

    $order_id = intval($_POST['order_id']);
    $order = wc_get_order($order_id);

    if (!$order) {
        wp_send_json_error(array('message' => 'Order not found'));
        return;
    }

    $customer_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
    $order_number = $order->get_order_number();
    $order_date = $order->get_date_created()->date('Y-m-d');
    $items_ordered = $order->get_items();
    $items_list = [];
    foreach ($items_ordered as $item) {
        $items_list[] = $item->get_name();
    }
    $total_amount = $order->get_total();
    $delivery_address = str_replace('<br/>', ', ', $order->get_formatted_billing_address());
    $customer_phone = $order->get_billing_phone();

    $template = get_option('wc_whatsapp_message_template', 'Dear {customer_name},\n\nThank you for shopping with us at {company_name}!\n\nWe have received your order with the following details:\n\n- Order Number: {order_number}\n- Order Date: {order_date}\n- Items Ordered:\n{items_list}\n- Total Amount: {total_amount}\n- Delivery Address: {delivery_address}\n\nTo proceed with your order, we kindly request you to confirm your Cash on Delivery (COD) order. Please reply to this message with your confirmation at your earliest convenience.\n\nIf you have any questions or need to make any changes to your order, please do not hesitate to contact us.\n\nThank you for choosing {company_name}.');

    $message = str_replace([
        '{customer_name}', '{order_number}', '{order_date}', '{items_list}', '{total_amount}', '{delivery_address}', '{company_name}'
    ], [
        $customer_name, $order_number, $order_date, implode("\n  - ", $items_list), $total_amount, $delivery_address, get_option('wc_whatsapp_company_name', 'Your Company Name')
    ], $template);

    $whatsapp_link = "https://wa.me/$customer_phone?text=" . urlencode($message);

    increment_usage_count();  // Increment usage count after sending message
    wp_send_json_success(array('link' => $whatsapp_link));
}

// Handle the AJAX request to send the WhatsApp status message
add_action('wp_ajax_send_whatsapp_status_message', 'send_whatsapp_status_message');

function send_whatsapp_status_message() {
    check_ajax_referer('whatsapp_nonce', '_ajax_nonce'); // Verify nonce

    if (!check_usage_limit()) {
        return;
    }

    $order_id = intval($_POST['order_id']);
    $order = wc_get_order($order_id);

    if (!$order) {
        wp_send_json_error(array('message' => 'Order not found'));
        return;
    }

    $customer_name = $order->get_billing_first_name() . ' ' . $order->get_billing_last_name();
    $order_number = $order->get_order_number();
    $order_status = wc_get_order_status_name($order->get_status());
    $customer_phone = $order->get_billing_phone();

    $template = get_option('wc_whatsapp_status_message_template', 'Dear {customer_name},\n\nWe wanted to update you on the status of your order #{order_number}.\n\nCurrent Status: {order_status}\n\nIf you have any questions or need further assistance, please feel free to contact us.\n\nThank you for choosing {company_name}.');

    $message = str_replace([
        '{customer_name}', '{order_number}', '{order_status}', '{company_name}'
    ], [
        $customer_name, $order_number, $order_status, get_option('wc_whatsapp_company_name', 'Your Company Name')
    ], $template);

    $whatsapp_link = "https://wa.me/$customer_phone?text=" . urlencode($message);

    increment_usage_count();  // Increment usage count after sending message
    wp_send_json_success(array('link' => $whatsapp_link));
}

// Include settings file
include plugin_dir_path(__FILE__) . 'admin-settings.php';
?>
